.. _examples-index:

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example shows how to create a simple histogram of the PMT signals. ">

.. only:: html

    .. figure:: /auto_examples/images/thumb/sphx_glr_plot_tot_histogram_thumb.png

        :ref:`sphx_glr_auto_examples_plot_tot_histogram.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/plot_tot_histogram

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Choosing the right colormap is important. A bad colormap like ``jet`` (standard in ROOT and mat...">

.. only:: html

    .. figure:: /auto_examples/images/thumb/sphx_glr_plot_colourmap_pitfalls_thumb.png

        :ref:`sphx_glr_auto_examples_plot_colourmap_pitfalls.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/plot_colourmap_pitfalls

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example shows how to create a zt-plot of a given DU and event ID. ">

.. only:: html

    .. figure:: /auto_examples/images/thumb/sphx_glr_plot_zt_thumb.png

        :ref:`sphx_glr_auto_examples_plot_zt.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/plot_zt

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example needs Astropy: `pip install astropy`.">

.. only:: html

    .. figure:: /auto_examples/images/thumb/sphx_glr_plot_astro_orca_thumb.png

        :ref:`sphx_glr_auto_examples_plot_astro_orca.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/plot_astro_orca
.. raw:: html

    <div style='clear:both'></div>


.. rst-class:: sphx-glr-signature

    `Generated by Sphinx-Gallery <http://sphinx-gallery.readthedocs.io>`_
